==> haskell-errors-2.1.3-6-i686.pkg.tar.xz: usr/share/haskell/register/haskell-errors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: errors
version: 2.1.3
id: errors-2.1.3-JC5aKrhjo2b91TTnOwOwbR
key: errors-2.1.3-JC5aKrhjo2b91TTnOwOwbR
license: BSD3
copyright: 2012, 2013 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
synopsis: Simplified error-handling
description:
    The one-stop shop for all your error-handling needs!  Just import
    "Control.Error".
    .
    This library encourages an error-handling style that directly uses the type
    system, rather than out-of-band exceptions.
category: Control, Error Handling
author: Gabriel Gonzalez
exposed: True
exposed-modules:
    Control.Error Control.Error.Safe Control.Error.Script
    Control.Error.Util Data.EitherR
abi: 8442238a2a6a2ab1ef4b8070bea9cdd1
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/errors-2.1.3
library-dirs: /usr/lib/ghc-8.0.2/site-local/errors-2.1.3
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/errors-2.1.3
hs-libraries: HSerrors-2.1.3-JC5aKrhjo2b91TTnOwOwbR
depends:
    base-4.9.1.0 safe-0.3.14-GsbXn9D9F3BDazVNcErzdQ
    transformers-0.5.2.0
    transformers-compat-0.5.1.4-IuFogs8HAVUJBWVNMhtssu
    unexceptionalio-0.3.0-2pCLthhElB6B0sx66UGiue
haddock-interfaces: /usr/share/doc/haskell-errors/html/errors.haddock
haddock-html: /usr/share/doc/haskell-errors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-errors-2.2.1-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-errors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: errors
version: 2.2.1
id: errors-2.2.1-KLpDlYJwzeoHgGxaSIdpLb
key: errors-2.2.1-KLpDlYJwzeoHgGxaSIdpLb
license: BSD3
copyright: 2012, 2013 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
synopsis: Simplified error-handling
description:
    The one-stop shop for all your error-handling needs!  Just import
    "Control.Error".
    .
    This library encourages an error-handling style that directly uses the type
    system, rather than out-of-band exceptions.
category: Control, Error Handling
author: Gabriel Gonzalez
exposed: True
exposed-modules:
    Control.Error Control.Error.Safe Control.Error.Script
    Control.Error.Util Data.EitherR
abi: 7ef1b36d3ee88b200e745b90bbde1e3b
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/errors-2.2.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/errors-2.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/errors-2.2.1
hs-libraries: HSerrors-2.2.1-KLpDlYJwzeoHgGxaSIdpLb
depends:
    base-4.9.1.0 exceptions-0.8.3-8AMTYj188ri8VOH6LXt0Fd
    safe-0.3.15-2Yd45VWFfdcKqKyispOifY
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq transformers-0.5.2.0
    transformers-compat-0.5.1.4-IuFogs8HAVUJBWVNMhtssu
    unexceptionalio-0.3.0-2pCLthhElB6B0sx66UGiue
haddock-interfaces: /usr/share/doc/haskell-errors/html/errors.haddock
haddock-html: /usr/share/doc/haskell-errors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
